@@ -61,37 +61,6 @@ module Gitlab
           # Equivalent to `git --git-path=#{repo_path} init [--bare]`
           repo = Rugged::Repository.init_at(repo_path, true)
           repo.close
-
-          # TODO: stop symlinking to the old hooks location in or after GitLab 12.0.
-          # https://gitlab.com/gitlab-org/gitaly/issues/1392
-          create_hooks(repo_path, Gitlab::Git::Hook.legacy_hooks_directory)
-        end
-
-        def create_hooks(repo_path, global_hooks_path)
-          local_hooks_path = File.join(repo_path, 'hooks')
-          real_local_hooks_path = :not_found
-
-          begin
-            real_local_hooks_path = File.realpath(local_hooks_path)
-          rescue Errno::ENOENT
-            # real_local_hooks_path == :not_found
-          end
-
-          # Do nothing if hooks already exist
-          unless real_local_hooks_path == File.realpath(global_hooks_path)
-            if File.exist?(local_hooks_path)
-              # Move the existing hooks somewhere safe
-              FileUtils.mv(
-                local_hooks_path,
-                "#{local_hooks_path}.old.#{Time.now.to_i}"
-              )
-            end
-
-            # Create the hooks symlink
-            FileUtils.ln_sf(global_hooks_path, local_hooks_path)
-          end
-
-          true
         end
       end
 
@@ -598,10 +567,6 @@ module Gitlab
         git_delete_refs(*ref_names)
       end
 
-      def delete_all_refs_except(prefixes)
-        delete_refs(*all_ref_names_except(prefixes))
-      end
-
       # Returns an Array of all ref names, except when it's matching pattern
       #
       # regexp - The pattern for ref names we don't want
@@ -695,7 +660,7 @@ module Gitlab
 
       def remove_remote(remote_name)
         # When a remote is deleted all its remote refs are deleted too, but in
-        # the case of mirrors we map its refs (that would usualy go under
+        # the case of mirrors we map its refs (that would usually go under
         # [remote_name]/) to the top level namespace. We clean the mapping so
         # those don't get deleted.
         rugged.config.delete("remote.#{remote_name}.fetch") if rugged.config["remote.#{remote_name}.mirror"]
@@ -913,6 +878,8 @@ module Gitlab
       def with_worktree(worktree_path, branch, sparse_checkout_files: nil, env:)
         base_args = %w[worktree add --detach]
 
+        run_git!(%w[config core.splitIndex true])
+
         # Note that we _don't_ want to test for `.present?` here: If the caller
         # passes an non nil empty value it means it still wants sparse checkout
         # but just isn't interested in any file, perhaps because it wants to
